package de.intevation.gnv.state.describedata;

import java.util.Collection;

/**
 * This interface describes some methods to retrieve the name of this <code>
 * Collection</code> and to determine if this <code>Collection</code> is a
 * single or multiselect object.
 *
 * @param <E> The objects in this class need to be of this type.
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 *
 */
public interface NamedCollection<E> extends Collection<E> {

    /**
     * Returns the name of this <code>Collection</code>.
     *
     * @return the name.
     */
    public String getName();

    /**
     * Determines if this <code>Collection</code> is a multi select object.
     *
     * @return true, if it is multi select, otherwise false.
     */
    public boolean isMultiSelect();

    /**
     * Change between single and multiselect.
     *
     * @param multiSelect true, if this object should be a multiselect,
     * otherwise false.
     */
    public void setMultiSelect(boolean multiSelect);
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :